import setuptools

setuptools.setup(
  name="blin",
  version="0.1.2",
  author="lemeni.com",
  description="Python client library for Blin API (natural language to API service)",
  packages=["blin"]
  )